==> reference1-1.0-sources.jar: one/xingyi/reference1/telephone/client/view/TelephoneNumberViewDebugInfo.java <==
package one.xingyi.reference1.telephone.client.view;
//Made by one.xingyi.core.filemaker.ViewDomDebugFileMaker
//Defn one.xingyi.reference1.telephone.ITelephoneNumberViewDefn
import java.lang.String;
public class TelephoneNumberViewDebugInfo {
/*
Deprecated: false
Original: one.xingyi.reference1.telephone.ITelephoneNumberViewDefn
    Entity:     one.xingyi.reference1.telephone.client.entitydefn.ITelephoneNumberViewClientEntity
    View:        one.xingyi.reference1.telephone.client.view.TelephoneNumberView
    Impl   :    one.xingyi.reference1.telephone.client.view.TelephoneNumberViewImpl
    ServerImpl: one.xingyi.reference1.telephone.client.viewcompanion.TelephoneNumberViewCompanion
    Original: one.xingyi.reference1.telephone.ITelephoneNumberDefn
        IServer:    one.xingyi.reference1.telephone.server.domain.ITelephoneNumber
        ServerImpl: one.xingyi.reference1.telephone.server.domain.TelephoneNumber
        Client:     one.xingyi.reference1.telephone.client.entitydefn.ITelephoneNumberClientEntity
        ServComp:   one.xingyi.reference1.telephone.server.companion.TelephoneNumberCompanion
        Lens:       TelephoneNumber
Fields: 1
    Field: number
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  lens path for views not done yet
        Lens name  lens for views not done yet
        Readonly   false
        Javascript functionlensforviewsnotdoneyet(){returnlens('number');};
        Templated: false
        Deprecated false

Deprecated: false
Original: one.xingyi.reference1.telephone.ITelephoneNumberDefn
    IServer:    one.xingyi.reference1.telephone.server.domain.ITelephoneNumber
    ServerImpl: one.xingyi.reference1.telephone.server.domain.TelephoneNumber
    Client:     one.xingyi.reference1.telephone.client.entitydefn.ITelephoneNumberClientEntity
    ServComp:   one.xingyi.reference1.telephone.server.companion.TelephoneNumberCompanion
    Lens:       TelephoneNumber
bookmarkAndUrl Optional.empty
Fields: 1
    Field: number
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  number/String
        Lens name  lens_TelephoneNumber_number
        Readonly   false
        Javascript functionlens_TelephoneNumber_number(){returnlens('number');};
        Templated: false
        Deprecated false
Get            Optional.empty
optionalGet    Optional.empty
Put            Optional.empty
Create         Optional.empty
CreateNoId     Optional.empty
Delete         Optional.empty
prototype:     Optional.empty
prototypeNoId: Optional.empty
Posts:         []
*/}

==> reference1-1.1-sources.jar: one/xingyi/reference1/telephone/client/view/TelephoneNumberViewDebugInfo.java <==
package one.xingyi.reference1.telephone.client.view;
//Made by one.xingyi.core.filemaker.ViewDomDebugFileMaker
//Defn one.xingyi.reference1.telephone.ITelephoneNumberViewDefn
import java.lang.String;
public class TelephoneNumberViewDebugInfo {
/*
Deprecated: false
Original: one.xingyi.reference1.telephone.ITelephoneNumberViewDefn
    Entity:     one.xingyi.reference1.telephone.client.entitydefn.ITelephoneNumberViewClientEntity
    View:        one.xingyi.reference1.telephone.client.view.TelephoneNumberView
    Impl   :    one.xingyi.reference1.telephone.client.view.TelephoneNumberViewImpl
    ServerImpl: one.xingyi.reference1.telephone.client.viewcompanion.TelephoneNumberViewCompanion
    Original: one.xingyi.reference1.telephone.ITelephoneNumberDefn
        IServer:    one.xingyi.reference1.telephone.server.domain.ITelephoneNumber
        ServerImpl: one.xingyi.reference1.telephone.server.domain.TelephoneNumber
        Client:     one.xingyi.reference1.telephone.client.entitydefn.ITelephoneNumberClientEntity
        ServComp:   one.xingyi.reference1.telephone.server.companion.TelephoneNumberCompanion
        Lens:       TelephoneNumber
Fields: 1
    Field: number
        StringPrimitiveType()
        Lens path  lens path for views not done yet
        Lens name  lens for views not done yet
        Readonly   false
        Javascript functionlensforviewsnotdoneyet(){returnlens('number');};
        Templated: false
        Deprecated false

Deprecated: false
Original: one.xingyi.reference1.telephone.ITelephoneNumberDefn
    IServer:    one.xingyi.reference1.telephone.server.domain.ITelephoneNumber
    ServerImpl: one.xingyi.reference1.telephone.server.domain.TelephoneNumber
    Client:     one.xingyi.reference1.telephone.client.entitydefn.ITelephoneNumberClientEntity
    ServComp:   one.xingyi.reference1.telephone.server.companion.TelephoneNumberCompanion
    Lens:       TelephoneNumber
bookmarkAndUrl Optional.empty
Fields: 1
    Field: number
        StringPrimitiveType()
        Lens path  number/String
        Lens name  lens_TelephoneNumber_number
        Readonly   false
        Javascript functionlens_TelephoneNumber_number(){returnlens('number');};
        Templated: false
        Deprecated false
Get            Optional.empty
optionalGet    Optional.empty
Put            Optional.empty
Create         Optional.empty
CreateNoId     Optional.empty
Delete         Optional.empty
prototype:     Optional.empty
prototypeNoId: Optional.empty
Posts:         []
*/}
